import torch
import triton
import triton.language as tl

@triton.jit
def _kernel_perchannel_absmax_quantize(
    x_ptr, 
    scale_ptr, 
    int_x_ptr,
    token_dim: tl.constexpr,
    chn_dim: tl.constexpr,
    power2_token_dim: tl.constexpr
):  
    off_b = tl.program_id(1) 
    x_off_set = off_b * token_dim * chn_dim
    col_idx = x_off_set + tl.program_id(0)

    col_start_ptr = x_ptr + col_idx   
    offs_m = tl.arange(0, power2_token_dim)
    col_ptrs = col_start_ptr + offs_m[:, None] * chn_dim

    col = tl.load(col_ptrs, mask = offs_m[:, None] < token_dim)
    scale_col_ptrs = scale_ptr + x_off_set//token_dim + tl.program_id(0)
    scale = tl.max(tl.abs(col)) / 127.
    rounded_col = col / scale
    rounded_col += 0.5 * tl.where(rounded_col >= 0, 1, -1)
    x_int8 = rounded_col.to(tl.int8)
        
    xint8_col_ptrs = int_x_ptr + col_idx + offs_m[:, None] * chn_dim
    tl.store(xint8_col_ptrs, x_int8, mask = offs_m[:, None] < token_dim)
    tl.store(scale_col_ptrs, scale)


def perchannel_absmax_quantize(x: torch.Tensor):
    x_int8 = torch.empty_like(x, dtype=torch.int8)
    if x.dim() == 3:
        scale = torch.empty((x.shape[-3], 1, x.shape[-1]), device=x.device, dtype=torch.float32)
    elif x.dim() == 4:
        scale = torch.empty((x.shape[-4], x.shape[-3], 1, x.shape[-1]), device=x.device, dtype=torch.float32)
    
    x = x.view(-1, x.shape[-2], x.shape[-1])
    B, L, C = x.shape

    power2_token_dim = triton.next_power_of_2(L)
    grid = (C, B, )
    _kernel_perchannel_absmax_quantize[grid](
        x_ptr=x, 
        scale_ptr=scale, 
        int_x_ptr=x_int8, 
        token_dim=L, 
        chn_dim=C,
        power2_token_dim = power2_token_dim
    )
    x_int8 = x_int8.permute(0, 1, 3, 2).contiguous().permute(0, 1, 3, 2)  
    return x_int8, scale