




import sys
import os
import pkgutil
import importlib

from .builder import get_default_compute_capabilities, OpBuilder


__deepspeed__ = True


try:
    import sat.ops.ops_builder  
    op_builder_dir = "sat.ops.ops_builder"
except ImportError:
    op_builder_dir = "ops_builder"

__op_builders__ = []

this_module = sys.modules[__name__]


def builder_closure(member_name):
    if op_builder_dir == "ops_builder":
        
        
        def _builder():
            from deepspeed.accelerator import get_accelerator
            builder = get_accelerator().create_op_builder(member_name)
            return builder

        return _builder
    else:
        
        from deepspeed.accelerator import get_accelerator
        builder = get_accelerator().get_op_builder(member_name)
        return builder



for _, module_name, _ in pkgutil.iter_modules([os.path.dirname(this_module.__file__)]):
    if module_name != 'all_ops' and module_name != 'builder':
        module = importlib.import_module(f".{module_name}", package=op_builder_dir)
        for member_name in module.__dir__():
            if member_name.endswith('Builder') and member_name != "OpBuilder" and member_name != "CUDAOpBuilder":
                
                
                this_module.__dict__[member_name] = builder_closure(member_name)
