import os

os.environ["CUDA_DEVICE_ORDER"] = "PCI_BUS_ID"

import torch
import torch.nn as nn
from transformers.models.llama.modeling_llama import (
    LlamaAttention,
    LlamaDecoderLayer,
    LlamaForCausalLM,
    LlamaMLP,
)
from transformers import LlamaTokenizer
import tqdm
import argparse
LENGTH = 2048

class Evaluator:
    def __init__(self, dataset, tokenizer, device):
        self.dataset = dataset
        self.tokenizer = tokenizer
        self.device = device

        
        def tokenize_function(examples):
            example = self.tokenizer(examples["text"])
            return example

        self.dataset = self.dataset.map(tokenize_function, batched=True)
        self.dataset.set_format(type="torch", columns=["input_ids"])

    @torch.no_grad()
    def evaluate(self, model, kernel_args):
        model.eval()
        
        total, hit = 0, 0
        for batch in self.dataset:
            input_ids = batch["input_ids"].to(self.device).unsqueeze(0)
            label = input_ids[:, -1]
            outputs = model(kernel_args, input_ids)
            last_token_logits = outputs.logits[:, -2, :]
            pred = last_token_logits.argmax(dim=-1)
            total += label.size(0)
            hit += (pred == label).sum().item()
        acc = hit / total
        return acc

from datasets import load_dataset

py_parser = argparse.ArgumentParser(add_help=False)
py_parser.add_argument("--quant_v", "-v", action='store_true', help="whether to quant v")
py_parser.add_argument("--minusk", "-k", action='store_true', help="whether to use k-k.mean()")
py_parser.add_argument("--type", type=str, default='token', help="which quant to use")
py_parser.add_argument("--load_max", action='store_true', help="load max from memory")
py_parser.add_argument("--attn_kernel_name", "-name", default="attn_qkv_int8_per_token_hd128_causal", help="which kernel to use")
kernel_args, _ = py_parser.parse_known_args()
model_dir = "./llama2-7b-hf-model"
tokenizer = LlamaTokenizer.from_pretrained(model_dir)
dataset = load_dataset("lambada", split="validation[:1000]")

evaluator = Evaluator(dataset, tokenizer, "cuda:0")

model_fp16 = LlamaForCausalLM.from_pretrained(
    model_dir, torch_dtype=torch.float16, device_map="cuda", attn_implementation = "sdpa"
)
acc_fp16 = evaluator.evaluate(model_fp16, kernel_args)
print(f"Original model (fp16) accuracy: {acc_fp16}")