from datasets import load_dataset
import torch
from datasets import load_metric 
import datasets




from transformers.models.llama import LlamaForCausalLM, LlamaTokenizer

def evaluate_humaneval(model, tokenizer, dataset, kernel_args):
    model.eval()
    device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
    results = []
    times = 0
    for sample in dataset:
        
        
        
        
        
        prompt = sample["question"]
        print(prompt)
        
        inputs = tokenizer(prompt, return_tensors="pt").to(device)

        with torch.no_grad():
            outputs = model.generate(kernel_args, **inputs)
        
        generated_code = tokenizer.decode(outputs[0], skip_special_tokens=True)
        results.append({
            "prompt": prompt,
            "generated_code": generated_code,
            "reference_code": sample["canonical_solution"]
        })
    
    return results

def compute_metrics(results):
    total = len(results)
    correct = 0
    for result in results:
        reference = result["reference_code"]
        generated = result["generated_code"]
        reference_tokens = reference.split()
        generated_tokens = generated.split()
        if reference_tokens == generated_tokens:
            correct += 1
    accuracy = correct / total
    print(f"HumanEval Accuracy: {accuracy:.4f}")

if __name__ == "__main__":
    import argparse
    
    py_parser = argparse.ArgumentParser(add_help=False)
    py_parser.add_argument("--quant_v", "-v", action='store_true', help="whether to quant v")
    py_parser.add_argument("--minusk", "-k", action='store_true', help="whether to use k-k.mean()")
    py_parser.add_argument("--type", type=str, default='block', help="which quant to use")
    py_parser.add_argument("--load_max", action='store_true', help="load max from memory")
    py_parser.add_argument("--attn_kernel_name", "-name", type=str, default='attn_qk_int8_per_block_hd128_causal', help="which kernel to use")
    kernel_args, _ = py_parser.parse_known_args()
    dataset = load_dataset("openai/gsm8k", "main", split='test')
    device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
    model_dir = "./llama2-7b-hf-model"
    
    model = LlamaForCausalLM.from_pretrained(model_dir,device_map=device, torch_dtype=torch.float16, attn_implementation = "eager")
    tokenizer = LlamaTokenizer.from_pretrained(model_dir)
    results = evaluate_humaneval(model, tokenizer, dataset, kernel_args)
    
    
    compute_metrics(results)
    print("lol")
    
    
