import os
from torch.profiler import profile, record_function, ProfilerActivity
os.environ["CUDA_DEVICE_ORDER"] = "PCI_BUS_ID"

import torch
import torch.nn as nn
from transformers.models.llama.modeling_llama import (
    LlamaAttention,
    LlamaDecoderLayer,
    LlamaForCausalLM,
    LlamaMLP,
)
from transformers import LlamaTokenizer
import tqdm
import argparse
LENGTH = 2048
py_parser = argparse.ArgumentParser(add_help=False)
py_parser.add_argument("--quant_v", "-v", action='store_true', help="whether to quant v")
py_parser.add_argument("--minusk", "-k", action='store_true', help="whether to use k-k.mean()")
py_parser.add_argument("--type", type=str, default='token', help="which quant to use")
py_parser.add_argument("--load_max", action='store_true', help="load max from memory")
py_parser.add_argument("--attn_kernel_name", "-name", type=str, required=False, help="which kernel to use")
kernel_args, _ = py_parser.parse_known_args()
py_parser = argparse.ArgumentParser(add_help=False)

model_dir = "./llama2-7b-hf-model"
tokenizer = LlamaTokenizer.from_pretrained(model_dir)

model = LlamaForCausalLM.from_pretrained(
    model_dir, torch_dtype=torch.float16, device_map="cuda", attn_implementation = "sdpa"
).eval()
with open('words.txt', 'r') as file:
    prompt = file.read()

inputs = tokenizer(prompt, return_tensors="pt")
input_ids = inputs["input_ids"][:, :1648]
inputs["input_ids"] = input_ids

prof = torch.profiler.profile(
    schedule=torch.profiler.schedule(wait=0, warmup=0, active=1, repeat=1),
    on_trace_ready=torch.profiler.tensorboard_trace_handler('./'),
    record_shapes=True,
    with_stack=True)
prof.start()
with profile(activities=[ProfilerActivity.CUDA]) as prof:
    with record_function("model_inference"):
        outputs = model(kernel_args, input_ids.cuda(), use_cache=False)
print(prof.key_averages().table(sort_by="cuda_time_total", row_limit=50))
