












from typing import TYPE_CHECKING

from ...utils import (
    OptionalDependencyNotAvailable,
    _LazyModule,
    is_torch_available,
    is_vision_available,
)


_import_structure = {
    "configuration_owlv2": [
        "Owlv2Config",
        "Owlv2TextConfig",
        "Owlv2VisionConfig",
    ],
    "processing_owlv2": ["Owlv2Processor"],
}

try:
    if not is_vision_available():
        raise OptionalDependencyNotAvailable()
except OptionalDependencyNotAvailable:
    pass
else:
    _import_structure["image_processing_owlv2"] = ["Owlv2ImageProcessor"]


try:
    if not is_torch_available():
        raise OptionalDependencyNotAvailable()
except OptionalDependencyNotAvailable:
    pass
else:
    _import_structure["modeling_owlv2"] = [
        "Owlv2Model",
        "Owlv2PreTrainedModel",
        "Owlv2TextModel",
        "Owlv2VisionModel",
        "Owlv2ForObjectDetection",
    ]

if TYPE_CHECKING:
    from .configuration_owlv2 import (
        Owlv2Config,
        Owlv2TextConfig,
        Owlv2VisionConfig,
    )
    from .processing_owlv2 import Owlv2Processor

    try:
        if not is_vision_available():
            raise OptionalDependencyNotAvailable()
    except OptionalDependencyNotAvailable:
        pass
    else:
        from .image_processing_owlv2 import Owlv2ImageProcessor

    try:
        if not is_torch_available():
            raise OptionalDependencyNotAvailable()
    except OptionalDependencyNotAvailable:
        pass
    else:
        from .modeling_owlv2 import (
            Owlv2ForObjectDetection,
            Owlv2Model,
            Owlv2PreTrainedModel,
            Owlv2TextModel,
            Owlv2VisionModel,
        )

else:
    import sys

    sys.modules[__name__] = _LazyModule(__name__, globals()["__file__"], _import_structure, module_spec=__spec__)
