













from typing import TYPE_CHECKING

from ...utils import OptionalDependencyNotAvailable, _LazyModule, is_torch_available, is_vision_available


_import_structure = {"configuration_rt_detr": ["RTDetrConfig"], "configuration_rt_detr_resnet": ["RTDetrResNetConfig"]}

try:
    if not is_vision_available():
        raise OptionalDependencyNotAvailable()
except OptionalDependencyNotAvailable:
    pass
else:
    _import_structure["image_processing_rt_detr"] = ["RTDetrImageProcessor"]

try:
    if not is_torch_available():
        raise OptionalDependencyNotAvailable()
except OptionalDependencyNotAvailable:
    pass
else:
    _import_structure["modeling_rt_detr"] = [
        "RTDetrForObjectDetection",
        "RTDetrModel",
        "RTDetrPreTrainedModel",
    ]
    _import_structure["modeling_rt_detr_resnet"] = [
        "RTDetrResNetBackbone",
        "RTDetrResNetPreTrainedModel",
    ]


if TYPE_CHECKING:
    from .configuration_rt_detr import RTDetrConfig
    from .configuration_rt_detr_resnet import RTDetrResNetConfig

    try:
        if not is_vision_available():
            raise OptionalDependencyNotAvailable()
    except OptionalDependencyNotAvailable:
        pass
    else:
        from .image_processing_rt_detr import RTDetrImageProcessor

    try:
        if not is_torch_available():
            raise OptionalDependencyNotAvailable()
    except OptionalDependencyNotAvailable:
        pass
    else:
        from .modeling_rt_detr import (
            RTDetrForObjectDetection,
            RTDetrModel,
            RTDetrPreTrainedModel,
        )
        from .modeling_rt_detr_resnet import (
            RTDetrResNetBackbone,
            RTDetrResNetPreTrainedModel,
        )

else:
    import sys

    sys.modules[__name__] = _LazyModule(__name__, globals()["__file__"], _import_structure, module_spec=__spec__)
