import sys
sys.path.insert(0, './pytorch-image-models')
import os
import torch
from torch.utils.data import DataLoader
from torchvision import datasets, transforms
import timm
from tqdm import tqdm



data_dir = './imagenet_val'

model = timm.create_model('vit_base_patch16_224.augreg2_in21k_ft_in1k', pretrained=True)
model = model.eval()


data_config = timm.data.resolve_model_data_config(model)
img_transforms = transforms.Compose([
    transforms.Resize((data_config['input_size'][-2], data_config['input_size'][-1])),
    transforms.ToTensor(),
    transforms.Normalize(mean=data_config['mean'], std=data_config['std'])
])


dataset = datasets.ImageFolder(root=data_dir, transform=img_transforms)
data_loader = DataLoader(dataset, batch_size=64, shuffle=False, num_workers=os.cpu_count())


def accuracy(output, target):
    with torch.no_grad():
        pred = torch.argmax(output, dim=1)
        correct = pred.eq(target.view_as(pred)).sum().item()
        return correct


total_correct = 0
total_images = 0

device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
model = model.to(device)

for inputs, targets in tqdm(data_loader, desc="Validating..."):
    inputs = inputs.to(device)
    targets = targets.to(device)

    outputs = model(inputs)
    total_correct += accuracy(outputs, targets)
    total_images += targets.size(0)
    

final_accuracy = (total_correct / total_images) * 100
print(f"Accuracy: {final_accuracy:.2f}%")
