
import numpy as np
import torch
from collections import OrderedDict


import hdf5storage

"""







"""


def weights2tensor(x, squeeze=False, in_features=None, out_features=None):
    """Modified version of https://github.com/albanie/pytorch-mcn
    Adjust memory layout and load weights as torch tensor
    Args:
        x (ndaray): a numpy array, corresponding to a set of network weights
           stored in column major order
        squeeze (bool) [False]: whether to squeeze the tensor (i.e. remove
           singletons from the trailing dimensions. So after converting to
           pytorch layout (C_out, C_in, H, W), if the shape is (A, B, 1, 1)
           it will be reshaped to a matrix with shape (A,B).
        in_features (int :: None): used to reshape weights for a linear block.
        out_features (int :: None): used to reshape weights for a linear block.
    Returns:
        torch.tensor: a permuted sets of weights, matching the pytorch layout
        convention
    """
    if x.ndim == 4:
        x = x.transpose((3, 2, 0, 1))

















    elif x.ndim == 3:  
        x = x[:,:,:,None]
        x = x.transpose((3, 2, 0, 1))
    elif x.ndim == 2:
        if x.shape[1] == 1:
            x = x.flatten()
    if squeeze:
        if in_features and out_features:
            x = x.reshape((out_features, in_features))
        x = np.squeeze(x)
    return torch.from_numpy(np.ascontiguousarray(x))


def save_model(network, save_path):
    state_dict = network.state_dict()
    for key, param in state_dict.items():
        state_dict[key] = param.cpu()
    torch.save(state_dict, save_path)


if __name__ == '__main__':
    
    





    
    mcn = hdf5storage.loadmat('models/modelcolor.mat')
    
    
    

    mat_net = OrderedDict()
    for idx in range(25):
        mat_net[str(idx)] = OrderedDict()
        count = -1
        
        print(idx)
        for i in range(13):
            
            if mcn['CNNdenoiser'][0][idx][0][i][0][0][0][0] == 'conv':
                
                count += 1
                w = mcn['CNNdenoiser'][0][idx][0][i][0][1][0][0]
               
                w = weights2tensor(w)
               
                
                b = mcn['CNNdenoiser'][0][idx][0][i][0][1][0][1]
                b = weights2tensor(b)
                print(b.shape)

                mat_net[str(idx)]['model.{:d}.weight'.format(count*2)] = w
                mat_net[str(idx)]['model.{:d}.bias'.format(count*2)] = b

    torch.save(mat_net, 'model_zoo/modelcolor.pth')
   














































































   
      



    
