import torch
import torch.nn.functional as F

class MHA(torch.nn.Module):

    def __init__(self):
        super().__init__()

        self.attn = torch.nn.MultiheadAttention(2048, 32, dropout=0.1, bias=True, batch_first=True)

    def forward(self, x, kv):
        
        batch_size, seq_len, num_heads, head_dim = x.size(0), x.size(1), 32, 64

        in_proj_weight = self.attn.in_proj_weight
        in_proj_bias = self.attn.in_proj_bias
        out_proj_weight = self.attn.out_proj.weight
        out_proj_bias = self.attn.out_proj.bias
        
        Bq, Bk, Bv = torch.chunk(in_proj_bias, 3, dim=0)
        Wq, Wk, Wv = torch.chunk(in_proj_weight, 3, dim=0)
        Q = F.linear(x.transpose(1, 0), Wq, Bq) 
        K = F.linear(kv.transpose(1, 0), Wk, Bk) 
        V = F.linear(kv.transpose(1, 0), Wv, Bv) 
        
        proj = torch.cat((Q, K, V), dim=2)
        proj = proj.unflatten(-1, (3, x.size(-1))).unsqueeze(0).transpose(0, -2).squeeze(-2).contiguous()
        q, k, v =proj[0], proj[1], proj[2]
        q = q.view(seq_len, batch_size * num_heads, head_dim).transpose(0, 1)
        k = k.view(seq_len, batch_size * num_heads, head_dim).transpose(0, 1)
        v = v.view(seq_len, batch_size * num_heads, head_dim).transpose(0, 1)
        q = q.view(batch_size, num_heads, seq_len, head_dim)
        k = k.view(batch_size, num_heads, seq_len, head_dim)
        v = v.view(batch_size, num_heads, seq_len, head_dim)
        
        attn_output = F.scaled_dot_product_attention(q, k, v, attn_mask=None, dropout_p=0, is_causal=False)
        attn_output = attn_output.permute(2, 0, 1, 3).contiguous().view(batch_size * seq_len, num_heads*head_dim)
        attn_output = F.linear(attn_output, out_proj_weight, out_proj_bias)
        attn_output = attn_output.view(seq_len, batch_size, attn_output.size(1))
        xx = attn_output.transpose(1, 0)
        
        std, _ = self.attn(x, kv, kv, need_weights=False)

        print(torch.nn.functional.cosine_similarity(std.reshape(1, -1), xx.reshape(1, -1)).item())

device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
model = MHA()
model.to(device)
model.eval()
x = torch.randn((2, 7200, 2048)).cuda()
kv = torch.randn((2, 7200, 2048)).cuda()
model(x, kv)
