B, H, S, D  = 4, 32, 16384, 64
causal = False

import argparse
parser = argparse.ArgumentParser(description="Example script.")
parser.add_argument('--func', type=str, help="Function name as a string")
args = parser.parse_args()
func = args.func
import os
import torch, time
torch.backends.cuda.enable_mem_efficient_sdp(False)
import torch.nn.functional as F
from attn_qk_int8_per_token import forward as attn_qk_int8_per_token
from attn_qk_int8_per_block import forward as attn_qk_int8_per_block
from attn_qk_int8_per_block_fixm import forward as attn_qk_int8_per_block_fixm
from attn_qk_int8_per_block_m0 import forward as attn_qk_int8_per_block_m0
from attn_qkv_int8_per_token import forward as attn_qkv_int8_per_token
from attn_qkv_int8_per_block import forward as attn_qkv_int8_per_block
from quant_per_token import per_token_int8
from quant_per_block import per_block_int8
from quant_v import perchannel_absmax_quantize

q = torch.randn((B, H, S, D), device='cuda', dtype=torch.float16)
k = torch.randn((B, H, S, D), device='cuda', dtype=torch.float16)
v = torch.randn((B, H, S, D), device='cuda', dtype=torch.float16)

q_int8_t, q_int8_t_scale, k_int8_t, k_int8_t_scale = per_token_int8(q, k)
q_int8_b, q_int8_b_scale, k_int8_b, k_int8_b_scale = per_block_int8(q, k)
v_int8, v_scale = perchannel_absmax_quantize(v)


def flops_test(func, causal):
    for _ in range(25):
        if func == 'fa2':
            F.scaled_dot_product_attention(q, k, v, is_causal=causal)
        elif func == 'attn_qk_int8_per_token': 
            attn_qk_int8_per_token(q_int8_t, k_int8_t, v, q_int8_t_scale, k_int8_t_scale)
        elif func == 'attn_qk_int8_per_block': 
            attn_qk_int8_per_block(q_int8_b, k_int8_b, v, q_int8_b_scale, k_int8_b_scale)
        elif func == 'attn_qk_int8_per_block_fixm': 
            attn_qk_int8_per_block_fixm(q_int8_b, k_int8_b, v, q_int8_b_scale, k_int8_b_scale)
        elif func == 'attn_qk_int8_per_block_m0': 
            attn_qk_int8_per_block_m0(q_int8_b, k_int8_b, v, q_int8_b_scale, k_int8_b_scale)
        elif func == 'attn_qkv_int8_per_token': 
            attn_qkv_int8_per_token(q_int8_t, k_int8_t, v_int8, q_int8_t_scale, k_int8_t_scale, v_scale)
        elif func == 'attn_qkv_int8_per_block': 
            attn_qkv_int8_per_block(q_int8_b, k_int8_b, v_int8, q_int8_b_scale, k_int8_b_scale, v_scale)
    torch.cuda.synchronize()
    _st = time.perf_counter()
    for _ in range(100):
        if func == 'fa2':
            F.scaled_dot_product_attention(q, k, v, is_causal=causal)
        elif func == 'attn_qk_int8_per_token': 
            attn_qk_int8_per_token(q_int8_t, k_int8_t, v, q_int8_t_scale, k_int8_t_scale)
        elif func == 'attn_qk_int8_per_block': 
            attn_qk_int8_per_block(q_int8_b, k_int8_b, v, q_int8_b_scale, k_int8_b_scale)
        elif func == 'attn_qk_int8_per_block_fixm': 
            attn_qk_int8_per_block_fixm(q_int8_b, k_int8_b, v, q_int8_b_scale, k_int8_b_scale)
        elif func == 'attn_qk_int8_per_block_m0': 
            attn_qk_int8_per_block_m0(q_int8_b, k_int8_b, v, q_int8_b_scale, k_int8_b_scale)
        elif func == 'attn_qkv_int8_per_token': 
            attn_qkv_int8_per_token(q_int8_t, k_int8_t, v_int8, q_int8_t_scale, k_int8_t_scale, v_scale)
        elif func == 'attn_qkv_int8_per_block': 
            attn_qkv_int8_per_block(q_int8_b, k_int8_b, v_int8, q_int8_b_scale, k_int8_b_scale, v_scale)
    torch.cuda.synchronize()
    end_time = time.perf_counter()
    latency = (end_time - _st) / 100
    FLOPS = B * H * S * S * D * 4 / latency / 1e12
    if causal:
        FLOPS/=2
    return FLOPS*1.0003   

if __name__ == "__main__":
    FLOPS = flops_test(func, causal)
    print(f"FLOPS: {FLOPS:.3f}") 
