# SageAttention
This repository contains the source code for the paper: "SageAttention: Accurate 8-Bit Attention for Plug-and-play Inference Acceleration."


## Base environment
```
pip install torch==2.4.0
pip install -U --index-url https://aiinfra.pkgs.visualstudio.com/PublicPackages/_packaging/Triton-Nightly/pypi/simple/ triton-nightly
pip install -r requirements.txt
```


## Accuracy and speed of SageAttention kernels
To directly obtain the speed (TOPS) and accuracy metrics (Cosine Similarity, Relative L1, and RMSE) of SageAttention kernels, run the following scripts:

`cd../../Kernels`
### SageAttn-T
`python SageAttn_T.py`

### SageAttn-B
`python SageAttn_B.py`

### SageAttn-vT
`python SageAttn_vT.py`

### SageAttn-vB
`python SageAttn_vB.py`



## End-to-end experiments with SageAttention
`cd Models`

First, you need to set up a virtual environment for your target model. For example, if you are interested in testing the video generation capabilities of CogvideoX with SageAttention, follow these steps:

1. Set up a virtual environment
`conda create --name cogvideo python=3.11`
`conda activate cogvideo`

2. Enter the corresponding directory
`cd cogvideo`

3. Refer to the README.md in the cogvideo directory for further instructions and install the required dependencies:
`pip install -r requirements.txt`

### LLama
`cd llama`
#### Test on WikiTest
`python eval_wikitest_acc.py -name attn_qk_int8_per_block_hd128_causal`

#### Test on MMLU
`python eval_mmlu_acc.py -name attn_qk_int8_per_block_hd128_causal`

#### Test on Lambda
`python eval_lambda_acc.py -name attn_qk_int8_per_block_hd128_causal`

### CogvideoX
```
cd /cogVideo/sat
python sample_video.py --base configs/cogvideox_2b_infer.yaml --type 'block' --attn_kernel_name  attn_qk_int8_per_block
```

### Unidiffuser
```
cd unidiffuser
python sample_multi_v1.py --mode=t2i --prompt="an elephant under the sea"
```

### UltraPixel
```
cd ultraPixel
python inference/test_t2i.py --type 'block'  --attn_kernel_name  attn_qk_int8_per_block
```

### TIMM
`cd timm`
#### Test on ImageNet or Imagenet-skectch
`python inference.py`

#### Test on Imagenet-Rendition
`python imagenet-r_inference.py`


